@@ -52,6 +52,7 @@
 		ROOM_TYPE_ONE_TO_ONE: 1,
 		ROOM_TYPE_GROUP: 2,
 		ROOM_TYPE_PUBLIC: 3,
+		ROOM_TYPE_CHANGELOG: 4,
 
 		/** @property {OCA.SpreedMe.Models.Room} activeRoom  */
 		activeRoom: null,
@@ -76,7 +77,8 @@
 		_participants: null,
 		/** @property {OCA.SpreedMe.Views.ParticipantView} _participantsView  */
 		_participantsView: null,
-		displayedGuestNameHint: false,
+		/** @property {OCA.SpreedMe.Views.CollectionsView} _collectionsView */
+		_collectionsView: null,
 		fullscreenDisabled: true,
 		_searchTerm: '',
 		guestNick: null,
@@ -112,16 +114,11 @@
 							});
 						});
 
-						//Add custom entry to create a new empty group or public room
+						// Add custom entry to create a new empty group or public room
 						if (OCA.SpreedMe.app._searchTerm === '') {
-							results.unshift({
-								id: "create-public-room",
-								displayName: t('spreed', 'New public conversation'),
-								type: "createPublicRoom"
-							});
 							results.unshift({
 								id: "create-group-room",
-								displayName: t('spreed', 'New group conversation'),
+								displayName: t('spreed', 'Enter name for a new conversation'),
 								type: "createGroupRoom"
 							});
 						} else {
@@ -137,7 +134,7 @@
 							});
 							results.push({
 								id: "create-public-room",
-								displayName: t('spreed', '{name} (public)', { name: shortenedName }),
+								displayName: shortenedName,
 								type: "createPublicRoom"
 							});
 						}
@@ -153,11 +150,11 @@
 				},
 				formatResult: function (element) {
 					if (element.type === "createPublicRoom") {
-						return '<span><div class="avatar icon-public"></div>' + escapeHTML(element.displayName) + '</span>';
+						return '<span><div class="avatar icon icon-public"></div>' + t('spreed', '{name} (public)', { name: element.displayName }) + '</span>';
 					}
 
 					if (element.type === "createGroupRoom" || element.type === 'group') {
-						return '<span><div class="avatar icon-contacts-dark"></div>' + escapeHTML(element.displayName) + '</span>';
+						return '<span><div class="avatar icon icon-contacts"></div>' + escapeHTML(element.displayName) + '</span>';
 					}
 
 					return '<span><div class="avatar" data-user="' + escapeHTML(element.id) + '" data-user-display-name="' + escapeHTML(element.displayName) + '"></div>' + escapeHTML(element.displayName) + '</span>';
@@ -176,10 +173,14 @@
 						this.connection.createGroupVideoCall(e.val, '');
 						break;
 					case 'createPublicRoom':
-						this.connection.createPublicVideoCall(OCA.SpreedMe.app._searchTerm);
+						if (OCA.SpreedMe.app._searchTerm !== '') {
+							this.connection.createPublicVideoCall(OCA.SpreedMe.app._searchTerm);
+						}
 						break;
 					case 'createGroupRoom':
-						this.connection.createGroupVideoCall('', OCA.SpreedMe.app._searchTerm);
+						if (OCA.SpreedMe.app._searchTerm !== '') {
+							this.connection.createGroupVideoCall('', OCA.SpreedMe.app._searchTerm);
+						}
 						break;
 					default:
 						console.log('Unknown type', e.object.type);
@@ -290,6 +291,17 @@
 			});
 
 			this._sidebarView.addTab('participants', { label: t('spreed', 'Participants'), icon: 'icon-contacts-dark' }, this._participantsView);
+
+			this._collectionsView = new OCA.SpreedMe.Views.CollectionsView({
+				room: this.activeRoom,
+				id: 'collectionsTabView'
+			});
+			this._collectionsView.listenTo(this._rooms, 'change:active', function(model, active) {
+				if (active) {
+					this.setRoom(model);
+				}
+			});
+			this._sidebarView.addTab('collections', { label: t('spreed', 'Collections'), icon: 'icon-category-integration' }, this._collectionsView);
 		},
 		_hideParticipantList: function() {
 			this._sidebarView.removeTab('participants');
@@ -325,9 +337,9 @@
 			var self = this;
 			this.signaling.syncRooms()
 				.then(function() {
+					self.stopListening(self.activeRoom, 'change:displayName');
 					self.stopListening(self.activeRoom, 'change:participantFlags');
 
-					var participants;
 					if (OC.getCurrentUser().uid) {
 						roomChannel.trigger('active', token);
 
@@ -336,20 +348,14 @@
 								self.activeRoom = room;
 							}
 						});
-						participants = self.activeRoom.get('participants');
-					} else {
-						// The public page supports only a single room, so the
-						// active room is already the room for the given token.
-						participants = self.activeRoom.get('participants');
-					}
-					// Disable video when entering a room with more than 5 participants.
-					if (participants && Object.keys(participants).length > 5) {
-						self.disableVideo();
 					}
 
 					self._emptyContentView.setActiveRoom(self.activeRoom);
 
 					self.setPageTitle(self.activeRoom.get('displayName'));
+					self.listenTo(self.activeRoom, 'change:displayName', function(model, value) {
+						self.setPageTitle(value);
+					});
 
 					self.updateContentsLayout();
 					self.listenTo(self.activeRoom, 'change:participantFlags', self.updateContentsLayout);
@@ -382,12 +388,10 @@
 			}
 
 			if (inCall) {
-				$('#video-speaking').show();
 				$('#videos').show();
 				$('#screens').show();
 				$('#emptycontent').hide();
 			} else {
-				$('#video-speaking').hide();
 				$('#videos').hide();
 				$('#screens').hide();
 				$('#emptycontent').show();
@@ -402,7 +406,9 @@
 			// happens it will overlap with the content area (the narrower the
 			// window the larger the overlap). Due to this the sidebar is opened
 			// automatically only if it will not overlap with the content area.
-			if ($(window).width() > 1111) {
+			if (this.activeRoom.get('type') === this.ROOM_TYPE_CHANGELOG) {
+				this._sidebarView.close();
+			} else if (this.activeRoom.get('type') !== this.ROOM_TYPE_CHANGELOG && $(window).width() > 1111) {
 				this._sidebarView.open();
 			}
 
@@ -412,6 +418,7 @@
 			});
 			this._sidebarView.setCallInfoView(callInfoView);
 
+			this._chatView.setRoom(this.activeRoom);
 			this._messageCollection.setRoomToken(this.activeRoom.get('token'));
 			this._messageCollection.receiveMessages();
 		},
@@ -447,6 +454,7 @@
 			this._messageCollection = new OCA.SpreedMe.Models.ChatMessageCollection(null, {token: null});
 			this._chatView = new OCA.SpreedMe.Views.ChatView({
 				collection: this._messageCollection,
+				model: this.activeRoom,
 				id: 'chatView',
 				guestNameModel: this._localStorageModel
 			});
@@ -547,7 +555,6 @@
 				this._chatView.$el.detach();
 				this._chatViewInMainView = false;
 
-				$('#video-speaking').hide();
 				$('#videos').hide();
 				$('#screens').hide();
 				$('#emptycontent').show();
@@ -572,16 +579,22 @@
 					return;
 				}
 
+				this.setPageTitle(null);
+
 				OC.Util.History.replaceState({}, OC.generateUrl('/apps/spreed'));
 			});
 
-			this._mediaControlsView = new OCA.SpreedMe.Views.MediaControlsView({
+			this._localVideoView = new OCA.Talk.Views.LocalVideoView({
 				app: this,
 				webrtc: OCA.SpreedMe.webrtc,
 				sharedScreens: OCA.SpreedMe.sharedScreens,
 			});
-			this._mediaControlsView.render();
-			$('#localVideoContainer .nameIndicator').replaceWith(this._mediaControlsView.$el);
+			this._localVideoView.render();
+			// Ensure that the local video is not visible in the initial page.
+			this._localVideoView.$el.addClass('hidden');
+			$('#videos').append(this._localVideoView.$el);
+
+			this._mediaControlsView = this._localVideoView._mediaControlsView;
 
 			$(document).on('click', this.onDocumentClick);
 			OC.Util.History.addOnPopStateHandler(_.bind(this._onPopState, this));
@@ -599,6 +612,15 @@
 				}
 			}.bind(this));
 
+			this.signaling.on('joinCall', function() {
+				// Disable video when joining a call in a room with more than 5
+				// participants.
+				var participants = this.activeRoom.get('participants');
+				if (participants && Object.keys(participants).length > 5) {
+					this.setVideoEnabled(false);
+				}
+			}.bind(this));
+
 			$(window).unload(function () {
 				this.connection.leaveCurrentRoom();
 				this.signaling.disconnect();
@@ -664,7 +686,7 @@
 				this.callbackAfterMedia = null;
 			}
 
-			$('.videoView').removeClass('hidden');
+			this._localVideoView.$el.removeClass('hidden');
 			this.initAudioVideoSettings(configuration);
 
 			localMediaChannel.trigger('startLocalMedia');
@@ -675,7 +697,7 @@
 				this.callbackAfterMedia = null;
 			}
 
-			$('.videoView').removeClass('hidden');
+			this._localVideoView.$el.removeClass('hidden');
 			this.initAudioVideoSettings(configuration);
 
 			if (OCA.SpreedMe.webrtc.capabilities.support) {
@@ -696,29 +718,19 @@
 		},
 		initAudioVideoSettings: function(configuration) {
 			if (configuration.audio !== false) {
-				this._mediaControlsView.hasAudio();
-
-				if (this._mediaControlsView.audioDisabled) {
-					this._mediaControlsView.disableAudio();
-				} else {
-					this._mediaControlsView.enableAudio();
-				}
+				this._mediaControlsView.setAudioAvailable(true);
+				this._mediaControlsView.setAudioEnabled(this._mediaControlsView.audioEnabled);
 			} else {
-				this._mediaControlsView.disableAudio();
-				this._mediaControlsView.hasNoAudio();
+				this._mediaControlsView.setAudioEnabled(false);
+				this._mediaControlsView.setAudioAvailable(false);
 			}
 
 			if (configuration.video !== false) {
-				this._mediaControlsView.hasVideo();
-
-				if (this._mediaControlsView.videoDisabled) {
-					this.disableVideo();
-				} else {
-					this.enableVideo();
-				}
+				this._mediaControlsView.setVideoAvailable(true);
+				this.setVideoEnabled(this._mediaControlsView.videoEnabled);
 			} else {
-				this.disableVideo();
-				this._mediaControlsView.hasNoVideo();
+				this.setVideoEnabled(false);
+				this._mediaControlsView.setVideoAvailable(false);
 			}
 		},
 		enableFullscreen: function() {
@@ -752,43 +764,12 @@
 
 			this.fullscreenDisabled = true;
 		},
-		enableVideoUI: function() {
-			var avatarContainer = this._mediaControlsView.$el.closest('.videoView').find('.avatar-container');
-			var localVideo = this._mediaControlsView.$el.closest('.videoView').find('#localVideo');
-
-			avatarContainer.hide();
-			localVideo.show();
-		},
-		enableVideo: function() {
-			if (this._mediaControlsView.enableVideo()) {
-				this.enableVideoUI();
-			}
-		},
-		hideVideo: function() {
-			var avatarContainer = this._mediaControlsView.$el.closest('.videoView').find('.avatar-container');
-			var localVideo = this._mediaControlsView.$el.closest('.videoView').find('#localVideo');
-
-			var avatar = avatarContainer.find('.avatar');
-			var guestName = localStorage.getItem("nick");
-			if (OC.getCurrentUser().uid) {
-				avatar.avatar(OC.getCurrentUser().uid, 128);
-			} else {
-				avatar.imageplaceholder('?', guestName, 128);
-				avatar.css('background-color', '#b9b9b9');
-				if (this.displayedGuestNameHint === false) {
-					OC.Notification.showTemporary(t('spreed', 'Set your name in the chat window so other participants can identify you better.'));
-					this.displayedGuestNameHint = true;
-				}
+		setVideoEnabled: function(videoEnabled) {
+			if (!this._mediaControlsView.setVideoEnabled(videoEnabled)) {
+				return;
 			}
 
-			avatarContainer.removeClass('hidden');
-			avatarContainer.show();
-			localVideo.hide();
-		},
-		disableVideo: function() {
-			this._mediaControlsView.disableVideo();
-			// Always hide the video, even if "disableVideo" returned "false".
-			this.hideVideo();
+			this._localVideoView.setVideoEnabled(videoEnabled);
 		},
 		// Called from webrtc.js
 		disableScreensharingButton: function() {
@@ -823,10 +804,7 @@
 			this._localStorageModel.fetch();
 		},
 		_onChangeGuestName: function(newDisplayName) {
-			var avatar = $('#localVideoContainer').find('.avatar');
-
-			avatar.imageplaceholder('?', newDisplayName, 128);
-			avatar.css('background-color', '#b9b9b9');
+			this._localVideoView.setAvatar(undefined, newDisplayName);
 
 			if (OCA.SpreedMe.webrtc) {
 				console.log('_onChangeGuestName.webrtc');
