@@ -332,7 +332,7 @@
 			method: 'DELETE',
 			async: false,
 			success: function () {
-				this._trigger('leaveCall', [token]);
+				this._trigger('leaveCall', [token, keepToken]);
 				this._leaveCallSuccess(token);
 				// We left the current call.
 				if (!keepToken && token === this.currentCallToken) {
@@ -461,8 +461,9 @@
 	};
 
 	// Connection to the internal signaling server provided by the app.
-	function Internal(/*settings*/) {
+	function Internal(settings) {
 		OCA.Talk.Signaling.Base.prototype.constructor.apply(this, arguments);
+		this.hideWarning = settings.hideWarning;
 		this.spreedArrayConnection = [];
 
 		this.pullMessagesFails = 0;
@@ -544,6 +545,21 @@
 		this._startPullingMessages();
 	};
 
+	OCA.Talk.Signaling.Internal.prototype._joinCallSuccess = function() {
+		if (this.hideWarning) {
+			return;
+		}
+
+		var numParticipants = Object.keys(OCA.SpreedMe.app.activeRoom.get('participants')).length +
+			OCA.SpreedMe.app.activeRoom.get('numGuests');
+		if (numParticipants <= 4) {
+			return;
+		}
+
+		var warning = t('spreed', 'Calls with more than 4 participants without an external signaling server can experience connectivity issues and cause high load on participating devices.');
+		OC.Notification.showTemporary(warning, { timeout: 30, type: 'warning' });
+	};
+
 	OCA.Talk.Signaling.Internal.prototype._doLeaveRoom = function(token) {
 		if (token === this.currentRoomToken && !this.roomCollection) {
 			window.clearInterval(this.roomPoller);
@@ -557,9 +573,18 @@
 		} else if(data.type === 'offer') {
 			console.log("OFFER", data);
 		}
+
+		// The RTCSessionDescription removes custom payload attributes in it's toJSON
+		// method. The one value we set is the nick, so we need to toJSON and toObject
+		// the description and add the nick to the payload again.
+		// {@see https://developer.mozilla.org/en-US/docs/Web/API/RTCSessionDescription/toJSON}
+		var tempString =  JSON.stringify(data);
+		var tempData = JSON.parse(tempString);
+		tempData.payload.nick = data.payload.nick;
+
 		this.spreedArrayConnection.push({
 			ev: "message",
-			fn: JSON.stringify(data),
+			fn: JSON.stringify(tempData),
 			sessionId: this.sessionId
 		});
 	};
@@ -612,7 +637,7 @@
 					switch(message.type) {
 						case "usersInRoom":
 							this._trigger('usersInRoom', [message.data]);
-							this._trigger("participantListChanged");
+							this._trigger('participantListChanged');
 							break;
 						case "message":
 							if (typeof(message.data) === 'string') {
@@ -633,6 +658,15 @@
 					// Request has been aborted. Ignore.
 				} else if (this.currentRoomToken) {
 					if (this.pullMessagesFails >= 3) {
+						if (OCA.SpreedMe.webrtc) {
+							// Force leaving the call in WebRTC; leaving the
+							// room indirectly runs
+							// signaling.leaveCurrentCall(), but if the
+							// signaling fails to leave the call no event will
+							// be triggered and the call will not be left from
+							// WebRTC point of view.
+							OCA.SpreedMe.webrtc.leaveCall();
+						}
 						OCA.SpreedMe.app.connection.leaveCurrentRoom();
 						return;
 					}
@@ -866,9 +900,9 @@
 	};
 
 	OCA.Talk.Signaling.Standalone.prototype.doSend = function(msg, callback) {
-		if (!this.connected && msg.type !== "hello") {
-			// Defer sending any messages until the hello rsponse has been
-			// received.
+		if (!this.connected && msg.type !== "hello" || this.socket === null) {
+			// Defer sending any messages until the hello response has been
+			// received and when the socket is open
 			this.pendingMessages.push([msg, callback]);
 			return;
 		}
@@ -1107,7 +1141,7 @@
 						this._trigger("usersLeft", [leftUsers]);
 					}
 					this._trigger("usersJoined", [joinedUsers]);
-					this._trigger("participantListChanged");
+					this._trigger('participantListChanged');
 				}
 				break;
 			case "leave":
@@ -1118,7 +1152,7 @@
 						delete this.joinedUsers[leftSessionIds[i]];
 					}
 					this._trigger("usersLeft", [leftSessionIds]);
-					this._trigger("participantListChanged");
+					this._trigger('participantListChanged');
 				}
 				break;
 			case "message":
@@ -1184,7 +1218,7 @@
 		switch (data.event.type) {
 			case "update":
 				this._trigger("usersChanged", [data.event.update.users || []]);
-				this._trigger("participantListChanged");
+				this._trigger('participantListChanged');
 				this.internalSyncRooms();
 				break;
 			default:
