@@ -1,27 +1,15 @@
 OC.L10N.register(
     "spreed",
     {
-    "Validate SSL certificate" : "Validera SSL-certifikat",
-    "Delete server" : "Ta bort server",
-    "Add new server" : "Lägg till ny server",
-    "Saved" : "Sparad",
-    "You deleted all STUN servers. As it is almost always needed, a default STUN server was added." : "Du raderade alla STUN-servrar. Eftersom det nästan alltid behövs har en standard STUN-server lagts till.",
-    "Shared secret" : "Delad hemlighet",
-    "TURN server shared secret" : "TURN server delade hemlighet",
-    "UDP and TCP" : "UDP och TCP",
-    "UDP only" : "endast UDP",
-    "TCP only" : "endast TCP",
-    "TURN server protocols" : "TURN server protokoll",
-    "New public conversation" : "Ny publik konversation",
-    "New group conversation" : "Ny gruppkonversation",
+    "Enter name for a new conversation" : "Ange namn för en ny konversation",
     "{name} (public)" : "{name} (publik)",
     "New conversation …" : "Ny konversation",
     "Participants" : "Deltagare",
+    "Collections" : "Samlingar",
     "Chat" : "Chat",
     "Talk" : "Talk",
     "Exit fullscreen (f)" : "Avsluta fullskärmsläge (f)",
     "Fullscreen (f)" : "Fullskärm (f)",
-    "Set your name in the chat window so other participants can identify you better." : "Ange ditt namn i chattfönstret så andra deltagare kan identifiera dig bättre. ",
     "Copy" : "Kopiera",
     "Copied!" : "Kopierat!",
     "Not supported!" : "Ej kompatibel!",
@@ -31,6 +19,7 @@ OC.L10N.register(
     "Start a conversation" : "Starta en konversation",
     "Share this file with others to discuss" : "Dela den här filen med andra för att diskutera",
     "Share" : "Dela",
+    "Room name can not be empty" : "Rumsnamn kan inte vara tomt",
     "Request password" : "Begär lösenord",
     "Error requesting the password." : "Fel vid begäran av lösenord.",
     "Please enter the password for this call" : "Var god ange lösenordet för detta samtal",
@@ -38,9 +27,11 @@ OC.L10N.register(
     "Password" : "Lösenord",
     "Cancel" : "Avbryt",
     "Submit" : "Skicka",
+    "Calls with more than 4 participants without an external signaling server can experience connectivity issues and cause high load on participating devices." : "Samtal med fler än 4 deltagare utan att en extern signalserver kan uppleva anslutningsproblem och orsaka hög belastning på deltagande enheter.",
     "Leave call" : "Lämna samtalet",
     "Join call" : "Gå med i samtal",
     "Start call" : "Starta samtal",
+    "Calls are disabled in this conversation." : "Samtal är inaktiverade i den här konversationen.",
     "Share link" : "Dela länk",
     "Change password" : "Byt lösenord",
     "Set password" : "Sätt lösenord",
@@ -56,6 +47,8 @@ OC.L10N.register(
     "No messages yet, start the conversation!" : "Inga meddelanden än, starta konversationen!",
     "New message …" : "Nytt meddelande",
     "Send" : "Skicka",
+    "You can not send messages, because the conversation is locked." : "Du kan inte skicka meddelanden, eftersom konversationen är låst.",
+    "The conversation is locked." : "Konversationen är låst.",
     "Guest" : "Gäst",
     "[Unknown user name]" : "[Okänt användarnam]",
     "Today" : "Idag",
@@ -79,6 +72,7 @@ OC.L10N.register(
     "Waiting for camera and microphone permissions" : "Väntar på godkännande att använda kamera och mikrofon",
     "Please, give your browser access to use your camera and microphone in order to use this app." : "Vänligen ge din webbläsare tillåtelse att använda din kamera och mikrofon för att kunna använda denna funktion.",
     "This conversation has ended" : "Denna konversation har avslutats",
+    "Set your name in the chat window so other participants can identify you better." : "Ange ditt namn i chattfönstret så andra deltagare kan identifiera dig bättre. ",
     "Mute audio" : "Stäng av ljudet",
     "Disable video" : "Stäng av video",
     "Share screen" : "Dela skärm",
@@ -86,11 +80,11 @@ OC.L10N.register(
     "Share a single window" : "Dela ett fönster",
     "Show your screen" : "Visa din skärm",
     "Stop screensharing" : "Stoppa skärmdelning",
-    "Unmute audio (m)" : "Ljud på (m)",
     "Mute audio (m)" : "Ljud av (m)",
+    "Unmute audio (m)" : "Ljud på (m)",
     "No audio" : "Inget ljud",
-    "Enable video (v)" : "Aktivera video (v)",
     "Disable video (v)" : "Inaktivera video (v)",
+    "Enable video (v)" : "Aktivera video (v)",
     "No Camera" : "Ingen kamera",
     "Screensharing is not supported by your browser." : "Skärmdelning fungerar inte i din nuvarande webbläsare.",
     "Screensharing requires the page to be loaded through HTTPS." : "Skärmdelning kräver HTTPS",
@@ -116,6 +110,10 @@ OC.L10N.register(
     "Never notify" : "Meddela aldrig",
     "Leave conversation" : "Lämna konversationen",
     "Delete conversation" : "Radera konversationen",
+    "You need to promote a new moderator before you can leave the conversation." : "Du måste tilldela en ny moderator innan du kan lämna konversationen.",
+    "Your screen" : "Din skärm",
+    "{participantName}'s screen" : "{participantName}'s skärm",
+    "Guest's screen" : "Gästskärm",
     "Close" : "Stäng",
     "Show screen" : "Visa skärm",
     "Enable video" : "Aktivera video",
@@ -124,9 +122,6 @@ OC.L10N.register(
     "Access to microphone & camera was denied" : "Tillgång till mikrofon och kamera blev nekad",
     "WebRTC is not supported in your browser" : "WebRTC är inte kompatibelt med din webbläsare",
     "Error while accessing microphone & camera" : "Kunde ej ansluta mikrofon och kamera",
-    "{participantName}'s screen" : "{participantName}'s skärm",
-    "Guest's screen" : "Gästskärm",
-    "Your screen" : "Din skärm",
     "a conversation" : "en konversation",
     "(Duration %s)" : "(Varaktighet%s)",
     "You attended a call with {user1}" : "Du deltog i ett samtal med {user1}",
@@ -138,6 +133,7 @@ OC.L10N.register(
     "_%n other_::_%n others_" : ["%n annan","%n andra"],
     "{actor} invited you to {call}" : "{actor} bjöd in dig till {call}",
     "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "Du bjöds in för ett <strong>pratrum</strong> eller hade ett <strong>samtal</strong>",
+    "The command does not exist" : "Kommandot finns inte",
     "{actor} created the conversation" : "{actor} skapade konversationen",
     "You created the conversation" : "Du skapade konversationen",
     "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} bytte namn på konversationen från \"%1$s\" till \"%2$s\"",
@@ -148,6 +144,10 @@ OC.L10N.register(
     "You joined the call" : "Du gick med i samtalet",
     "{actor} left the call" : "{actor} lämnade samtalet",
     "You left the call" : "Du lämnade samtalet",
+    "{actor} unlocked the conversation" : "{actor} låste upp konversationen",
+    "You unlocked the conversation" : "Du låste upp konversationen",
+    "{actor} locked the conversation" : "{actor} låste konversationen",
+    "You locked the conversation" : "Du låste konversationen",
     "{actor} allowed guests" : "{actor} tillåter gäster",
     "You allowed guests" : "Du tillåter gäster",
     "{actor} disallowed guests" : "{actor} tillåter inte gäster",
@@ -181,61 +181,100 @@ OC.L10N.register(
     "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Samtal med {user1}, {user2}, {user3}, {user4} och {user5} (Varade {duration})",
     "Talk to %s" : "Prata med %s",
     "File is not shared, or shared but not with the user" : "Filen delas inte eller delas men inte med användaren",
-    "Password request: %s" : "Lösenordsförfrågan: %s",
-    "_%n other guest_::_%n other guests_" : ["%n annan gäst","%n andra gäster"],
-    ", " : ",",
     "%s invited you to a conversation." : "%s bjöd in dig till en konversation.",
     "You were invited to a conversation." : "Du blev inbjuden till en konversation.",
     "Conversation invitation" : "Inbjudan till konversation",
     "Click the button below to join." : "Klicka på knappen nedan för att gå med.",
     "Join »%s«" : "Anslut »%s«",
-    "Join now" : "Anslut nu",
+    "Password request: %s" : "Lösenordsförfrågan: %s",
+    "Private conversation" : "Privat konversation",
     "{user} sent you a private message" : "{user} skickade dig ett privat meddelande",
     "{user} sent a message in conversation {call}" : "{user} skickade ett meddelande i konversation {call}",
-    "{user} sent a message in a conversation" : "{user} skickade ett meddelande i en konversation",
     "A deleted user sent a message in conversation {call}" : "En raderad användare skickade ett meddelande i konversation {call}",
-    "A deleted user sent a message in a conversation" : "En raderad användare skickade ett meddelande i en konversation",
     "A guest sent a message in conversation {call}" : "En gäst skickade ett meddelande i konversation {call}",
-    "A guest sent a message in a conversation" : "En gäst skickade ett meddelande i en konversation",
     "{user} mentioned you in a private conversation" : "{user} nämnde dig i en privat konversation",
     "{user} mentioned you in conversation {call}" : "{user} nämnde dig i konversation {call}",
-    "{user} mentioned you in a conversation" : "{user} nämnde dig i en konversation",
     "A deleted user mentioned you in conversation {call}" : "En raderad användare nämnde dig i konversation {call}",
-    "A deleted user mentioned you in a conversation" : "En raderad användare nämnde dig i en konversation",
     "A guest mentioned you in conversation {call}" : "En gäst nämnde dig i konversation {call}",
-    "A guest mentioned you in a conversation" : "En gäst nämnde dig i en konversation",
     "%s invited you to a private conversation" : "%s bjöd in dig till en privat konversation",
     "{user} invited you to a private conversation" : "{user} bjöd in dig till en privat konversation",
     "%s invited you to a group conversation: %s" : "%s bjöd in dig till en gruppkonversation: %s",
     "{user} invited you to a group conversation: {call}" : "{user} bjöd in dig till en gruppkonversation: {call}",
-    "%s invited you to a group conversation" : "%s bjöd in dig till en gruppkonversation",
-    "{user} invited you to a group conversation" : "{user} bjöd in dig till en gruppkonversation",
     "{user} wants to talk with you" : "{user} vill prata med dig",
     "A group call has started in {call}" : "Ett gruppsamtal har startats i {call}",
-    "A group call has started" : "Ett gruppsamtal har startats",
     "{email} requested the password to access {file}" : "{email} begärde lösenordet för åtkomst till {file}",
     "Someone requested the password to access {file}" : "Någon begärde lösenordet för att komma åt {file}",
     "Invalid date, date format must be YYYY-MM-DD" : "Felaktigt datum, datumformat måste vara ÅÅÅÅ-MM-DD",
     "Conversation not found" : "Konversationen hittades inte",
     "Path is already shared with this room" : "Sökvägen är redan delad med detta rum",
     "Video & audio-conferencing using WebRTC" : "Video- och ljudkonferens med WebRTC",
-    "This call is password-protected" : "Detta samtal är lösenordsskyddat",
-    "The password is wrong. Try again." : "Lösenordet är fel. Försök igen.",
-    "Signaling server" : "Signalerar server",
-    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "En extern signalserver kan eventuellt användas för större installationer. Lämna tomt för att använda den interna signalservern.",
+    "None" : "Ingen",
+    "User" : "Användare",
+    "Everyone" : "Alla",
+    "Disabled" : "Inaktiverad",
+    "Moderators" : "Moderatorer",
+    "Users" : "Användare",
+    "TURN server URL" : "TURN-server URL",
+    "Validate SSL certificate" : "Validera SSL-certifikat",
+    "Delete this server" : "Ta bort denna server",
+    "STUN server URL" : "STUN-server URL",
+    "TURN server secret" : "TURN-server hemlighet",
+    "TURN server protocols" : "TURN server protokoll",
+    "UDP and TCP" : "UDP och TCP",
+    "UDP only" : "endast UDP",
+    "TCP only" : "endast TCP",
+    "Test this server" : "Testa denna server",
+    "Limit to groups" : "Begränsa till grupper",
+    "When at least one group is selected, only people of the listed groups can be part of conversations." : "När minst en grupp väljs kan bara personer i de angivna grupperna ingå i konversationer.",
+    "Guests can still join public conversations." : "Gäster kan fortfarande delta i publika konversationer.",
+    "Users that can not use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Användare som inte kan använda Talk längre kommer fortfarande att listas som deltagare i sina tidigare samtal och även deras chattmeddelanden kommer att behållas.",
+    "Limit app usage to groups." : "Begränsa app-användning till grupper",
+    "Save changes" : "Spara ändringar",
+    "Saving …" : "Sparar ...",
+    "Saved!" : "Sparat!",
+    "Commands" : "Kommandon",
+    "Command" : "Kommando",
+    "Script" : "Skript",
+    "Response to" : "Svar till",
+    "Enabled for" : "Aktiverad för",
+    "Select a room to link to the collection" : "Välj ett rum för att länka till samlingen",
+    "Select room" : "Välj rum",
+    "Signaling servers" : "Signalservrar",
+    "Saved" : "Sparad",
+    "Add a new server" : "Lägg till ny server",
+    "An external signaling server should optionally be used for larger installations. Leave empty to use the internal signaling server." : "En extern signalserver bör eventuellt användas för större installationer. Lämna tomt för att använda den interna signalservern.",
+    "Please note that calls with more than 4 participants without external signaling server, participants can experience connectivity issues and cause high load on participating devices." : "Observera att samtal med fler än 4 deltagare utan extern signalserver kan uppleva anslutningsproblem och orsaka hög belastning på deltagande enheter.",
+    "Don't warn about connectivity issues in calls with more than 4 participants" : "Varna inte om anslutningsproblem i samtal med fler än 4 deltagare",
+    "Shared secret" : "Delad hemlighet",
     "STUN servers" : "STUN-servrar",
     "A STUN server is used to determine the public IP address of participants behind a router." : "En STUN-server används för att bestämma den offentliga IP-adressen av deltagare bakom en router.",
+    "TURN servers" : "TURN-servers",
+    "A TURN server is used to proxy the traffic from participants behind a firewall." : "En TURN-servern används för att tunnla trafiken för användare som sitter bakom en brandvägg.",
+    "This call is password-protected" : "Detta samtal är lösenordsskyddat",
+    "The password is wrong. Try again." : "Lösenordet är fel. Försök igen.",
+    "Specify commands the users can use in chats" : "Ange kommandon som användare kan använda i chattar",
+    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "En extern signalserver kan eventuellt användas för större installationer. Lämna tomt för att använda den interna signalservern.",
     "TURN server" : "TURN server",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN-servern används för att tunnla trafiken för användare som sitter bakom en brandvägg.",
     "%s Talk on your mobile devices" : "%s Talk på dina mobila enheter",
     "Join conversations at any time, any where, on any device." : "Anslut dig till konversationer när som helst, var som helst och på valfri enhet.",
     "Android app" : "Android-app",
     "iOS app" : " iOS-app",
-    "(group)" : " (grupp)",
-    "and you" : "och du",
-    "… %s" : "… %s",
-    "%s …" : "%s …",
-    "… %s …" : "… %s …",
+    "room" : "rum",
+    "Signaling server URL" : "Signalserver URL",
+    "Delete server" : "Ta bort server",
+    "Add new server" : "Lägg till ny server",
+    "You deleted all STUN servers. As it is almost always needed, a default STUN server was added." : "Du raderade alla STUN-servrar. Eftersom det nästan alltid behövs har en standard STUN-server lagts till.",
+    "TURN candidate generation failed, please check the settings." : "TURN-generering misslyckades, kontrollera inställningarna.",
+    "The TURN server settings are valid." : "TURN-serverns inställningar är giltiga.",
+    "Checking TURN server {server}" : "Kontrollerar TURN-servern {server}",
+    "TURN server shared secret" : "TURN server delade hemlighet",
+    "Test server" : "Testa server",
+    "New public conversation" : "Ny publik konversation",
+    "New group conversation" : "Ny gruppkonversation",
+    "Password request by %s" : "Lösenordet efterfrågas av %s",
+    "_%n other guest_::_%n other guests_" : ["%n annan gäst","%n andra gäster"],
+    ", " : ",",
     "%s mentioned you in a private conversation" : "%s nämnde dig i en privat konversation",
     "%s mentioned you in a group conversation: %s" : "%s nämnde dig i en gruppkonversation: %s",
     "{user} mentioned you in a group conversation: {call}" : "{user} nämnde dig i en gruppkonversation: {call}",
@@ -247,7 +286,18 @@ OC.L10N.register(
     "A guest mentioned you in a group conversation: %s" : "En gäst nämnde dig i en gruppkonversation: %s",
     "A guest mentioned you in a group conversation: {call}" : "En gäst nämnde dig i en gruppkonversation: {call}",
     "A guest mentioned you in a group conversation" : "En gäst nämnde dig i en gruppkonversation",
-    "Password request by %s" : "Lösenordet efterfrågas av %s",
-    "{email} requested the password to access a share" : "{email} begärde lösenordet för att komma åt en delning"
+    "%s invited you to a group conversation" : "%s bjöd in dig till en gruppkonversation",
+    "{user} invited you to a group conversation" : "{user} bjöd in dig till en gruppkonversation",
+    "A group call has started" : "Ett gruppsamtal har startats",
+    "{email} requested the password to access a share" : "{email} begärde lösenordet för att komma åt en delning",
+    "Unnamed conversation" : "Namnlös konversation",
+    "Signaling server" : "Signalerar server",
+    "Join now" : "Anslut nu",
+    "{user} sent a message in a conversation" : "{user} skickade ett meddelande i en konversation",
+    "A deleted user sent a message in a conversation" : "En raderad användare skickade ett meddelande i en konversation",
+    "A guest sent a message in a conversation" : "En gäst skickade ett meddelande i en konversation",
+    "{user} mentioned you in a conversation" : "{user} nämnde dig i en konversation",
+    "A deleted user mentioned you in a conversation" : "En raderad användare nämnde dig i en konversation",
+    "A guest mentioned you in a conversation" : "En gäst nämnde dig i en konversation"
 },
 "nplurals=2; plural=(n != 1);");
